@@ -230,7 +230,7 @@ class TimerMMAcquisition(MMAcquisition):
         )
         self.acq_eng.set_pause(True)
         self.acquisitions.set_pause(True)
-        self.timer.setInterval(self.start_interval * 1_000)
+        self.timer.setInterval(int(self.start_interval * 1_000))
         self.timer.start()
 
     @pyqtSlot()
